import React, { useState, useRef, useEffect } from 'react'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft, faChevronDown, faTimes, faImage  } from '@fortawesome/free-solid-svg-icons';
import { DummyKtp } from '../../../assets/images'
import { Link } from 'react-router-dom';


const Verify = () => {

    const BASE_URL = process.env.REACT_APP_BASE_URL
    const API_KEY = process.env.REACT_APP_API_KEY

    const [isSelectOpen, setIsSelectOpen] = useState(false);
    const [errorMessage, setErrorMessage] = useState('');
    const [selectedImageName, setSelectedImageName] = useState('');
    const fileInputRef = useRef(null);
    const [showResult, setShowResult] = useState(false);
    const [applicationId, setApplicationId] = useState('');
    const [imageUrl, setImageUrl] = useState('');
    const [isLoading, setIsLoading] = useState(false);

    const [applicationIds, setApplicationIds] = useState([]);

    // Example usage:
    const data = {
        nik: "21710121748901",
        district: "BATAM KOTA",
        name: "HANDOKO",
        city: "KOTA BATAM",
        dob: "BANJARMASIN, 12-12-1974",
        state: "PROVINSI KEPULAUAN RIAU",
        gender: "LAKI-LAKI",
        religion: "KRISTEN",
        bloodType: "A",
        maritalStatus: "KAWIN",
        address: "GOLDEN LAND BLOK FN NO.39",
        occupation: "WIRASWASTA",
        rtRw: "002/013",
        nationality: "WNI",
        village: "TAMAN BALOI",
        imageUrl: DummyKtp, // Replace this with the actual image path
        dark: false,
        blur: false,
        grayscale: false,
        flashlight: false,
    };

    useEffect(() => {
        const fetchApplicationIds = async () => {
            try {
                setIsLoading(true)

                const url = `${BASE_URL}/application/list`;
                console.log('Fetching URL:', url); 
                
                const response = await fetch(url, {
                    method: 'GET',
                    headers: {
                        'accept': 'application/json',
                        'x-api-key': `${API_KEY}`,
                    },
                });
    
                const data = await response.json();
    
                if (data.status_code === 200) {
                    const ids = data.details.data.map(app => app.id);
                    console.log('Application Id: ' + ids); 
                    setApplicationIds(data.details.data); 
                } else {
                    console.error('Failed to fetch data:', data.details.message);
                }
            } catch (error) {
                console.error('Error fetching application IDs:', error);
            } finally {
                setIsLoading(false)
            }
        };
    
        fetchApplicationIds();
    }, []);

    const handleFocus = () => {
        setIsSelectOpen(true);
    };

    const handleBlur = () => {
        setIsSelectOpen(false);
    };

    const handleImageUpload = (event) => {
        const file = event.target.files[0];

        if (file && (file.type === 'image/jpeg' || file.type === 'image/jpg')) {
            setSelectedImageName(file.name);
            setErrorMessage('');
        } else {
            alert('Please upload a valid image file (JPG, JPEG).');
        }
    };

    const handleImageCancel = () => {
        setSelectedImageName('');
        if (fileInputRef.current) {
            fileInputRef.current.value = '';
        }
    };

    const handleCheckClick = async () => {
        console.log('Verify - OCR Ktp')
        setShowResult(true)
    };

    const getValueStyle = (value) => ({
        color: value ? 'green' : 'red',
    });
    

    return (
        <div className='container' style={{ marginTop: '3%' }}>
            {/* Inject keyframes for the spinner */}
            <style>
                {`
                @keyframes spin {
                    0% { transform: rotate(0deg); }
                    100% { transform: rotate(360deg); }
                }
                `}
            </style>

            {isLoading && (
                <div style={styles.loadingOverlay}>
                    <div style={styles.spinner}></div>
                    <p style={styles.loadingText}>Loading...</p>
                </div>
            )}
            {/* Welcome Message */}
            <div className="row-card border-left border-primary shadow mb-4" style={{ backgroundColor: '#E2FBEA' }}>
                <div className="d-flex flex-column justify-content-start align-items-start p-4">
                <div>
                    <h4 className="mb-3 text-start">
                    <i className="fas fa-warning fa-bold me-3"></i>Alert
                    </h4>
                    <p className="mb-0 text-start">
                    Get started now by creating an Application ID and explore all the demo services available on the dashboard.
                    Experience the ease and flexibility of trying out all our features firsthand.
                    </p>
                </div>
                {/* Tombol di bawah teks */}
                <div className="d-flex flex-row mt-3">
                    <Link to="/createApps" style={{ textDecoration: 'none' }}>
                        <button className="btn d-flex justify-content-center align-items-center me-2" style={{ backgroundColor: '#0542CC' }}>
                            <i className="fas fa-plus text-white me-2"></i>
                            <p className="text-white mb-0">Create New App ID</p>
                        </button>
                    </Link>
                </div>
                </div>
            </div>

            {/* Section */}
            <div style={
                {
                    padding: '20px',
                    border: '0.1px solid rgba(0, 0, 0, 0.2)',
                    borderLeft: '4px solid #0542cc',
                    borderRadius: '10px',
                    width: '100%',
                  }
            }>
                {/* Application ID Selection */}
                <div className="form-group row align-items-center"> {/* Added align-items-center for vertical alignment */}
                    <div className="col-md-6">
                        <div style={styles.selectWrapper}>
                            <select
                                id="applicationId"
                                className="form-control"
                                style={styles.select}
                                value={applicationId}
                                onChange={(e) => setApplicationId(e.target.value)}
                                onFocus={handleFocus}
                                onBlur={handleBlur}
                            >
                                <option value="">Select Application ID</option>
                                {applicationIds.map((app) => (
                                    <option key={app.id} value={app.id}>
                                        {app.name}
                                    </option>
                                ))}
                            </select>
                            <FontAwesomeIcon
                                icon={isSelectOpen ? faChevronDown : faChevronLeft}
                                style={styles.chevronIcon}
                            />
                        </div>
                    </div>

                    <div className="col-md-6">
                        <p className="text-secondary" style={{ fontSize: '16px', fontWeight: '400', margin: '0', marginTop: '8px' }}> {/* Adjusted margins */}
                            Remaining Quota
                        </p>
                        <div style={styles.remainingQuota}>
                            <span style={styles.quotaText}>0</span>
                            <span style={styles.timesText}>(times)</span>
                        </div>
                    </div>
                </div>

                {/* Upload Section */}
                <div className='col-md-6'>
                    <div className="form-group mt-4">
                        <label htmlFor="uploadPhoto" style={{ fontWeight: 600, fontSize: '14px', color: '#212529' }}>Upload your e-KTP Photo</label>
                        <div
                            style={styles.uploadArea}
                            onClick={() => document.getElementById('fileUpload').click()}
                        >
                            <i className="fas fa-cloud-upload-alt" style={styles.uploadIcon}></i>
                            <p style={styles.uploadText}>Drag and Drop Here</p>
                            <p>Or</p>
                            <a href="#">Browse</a>
                            <p className="text-muted">Recommended size: 300x300 (Max File Size: 2MB)</p>
                            <p className="text-muted">Supported file types: JPG, JPEG</p>
                        </div>
                        <input
                            type="file"
                            id="fileUpload"
                            ref={fileInputRef}
                            style={{ display: 'none' }}
                            accept="image/jpeg, image/png, image/jpg"
                            onChange={handleImageUpload}
                        />
                        {errorMessage && (
                            <small style={styles.uploadError}>{errorMessage}</small>
                        )}
                    </div>
                </div>

                {/* Display uploaded image name */}
                {selectedImageName && (
                    <div className="col-md-6 mt-4">
                        <div style={styles.fileWrapper}>
                            <FontAwesomeIcon icon={faImage} style={styles.imageIcon} />
                            <div style={{ marginRight: '18rem', marginTop: '0.2rem' }}>
                                <h5>Uploaded File:</h5>
                                <p>{selectedImageName}</p>
                            </div>
                            <div style={{ display: 'flex', justifyContent: 'flex-end' }}>
                                <FontAwesomeIcon
                                    icon={faTimes}
                                    style={styles.closeIcon}
                                    onClick={handleImageCancel}
                                />
                            </div>
                        </div>
                    </div>
                )}

                {/* Submit Button */}
                <div style={styles.submitButton}>
                    <button onClick={handleCheckClick} className="btn d-flex justify-content-center align-items-center me-2" style={{ backgroundColor: '#0542CC' }}>
                        <p className="text-white mb-0">Check Now</p>
                    </button>
                </div>

                {/* Result Section */}
                {showResult && (
                    <div style={{ display: 'flex', flexDirection: 'row', marginTop: '20px' }}>
                        <div style={{ flex: 1, marginRight: '10px' }}>
                            <h1 style={{ color: '#0542cc' }}>Results</h1>
                            <div style={styles.resultContainer}>
                                <div style={{ display: 'flex', flexDirection: 'row' }}>
                                    <table style={{ ...styles.tableStyle, marginRight: '10px' }}>
                                        <tbody>
                                            <tr>
                                                <td style={styles.tableCell}>NIK</td>
                                                <td style={styles.tableCell}>{data.nik}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>District</td>
                                                <td style={styles.tableCell}>{data.district}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Name</td>
                                                <td style={styles.tableCell}>{data.name}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>City</td>
                                                <td style={styles.tableCell}>{data.city}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Date of Birth</td>
                                                <td style={styles.tableCell}>{data.dob}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>State</td>
                                                <td style={styles.tableCell}>{data.state}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Gender</td>
                                                <td style={styles.tableCell}>{data.gender}</td>
                                            </tr>
                                        </tbody>
                                    </table>
                                    <table style={styles.tableStyle}>
                                        <tbody>
                                            <tr>
                                                <td style={styles.tableCell}>Religion</td>
                                                <td style={styles.tableCell}>{data.religion}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Blood Type</td>
                                                <td style={styles.tableCell}>{data.bloodType}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Marital Status</td>
                                                <td style={styles.tableCell}>{data.maritalStatus}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Address</td>
                                                <td style={styles.tableCell}>{data.address}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Occupation</td>
                                                <td style={styles.tableCell}>{data.occupation}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>RT/RW</td>
                                                <td style={styles.tableCell}>{data.rtRw}</td>
                                            </tr>
                                            <tr>
                                                <td style={styles.tableCell}>Nationality</td>
                                                <td style={styles.tableCell}>{data.nationality}</td>
                                            </tr>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                        <div style={{ flex: 1, textAlign: 'center', marginTop: '3rem' }}>
                            <img
                                src={data.imageUrl}
                                alt="KTP"
                                style={{ width: '292px', height: '172px', borderRadius: '8px', marginBottom: '10px' }}
                            />
                            <div style={{ width: '292px', display: 'flex', flexDirection: 'column', alignItems: 'flex-start', marginLeft: '8.2rem' }}>
                                <div style={{ display: 'flex', flexDirection: 'row', justifyContent: 'space-between', width: '100%' }}>
                                    <p style={getValueStyle(data.dark)}>Dark: {data.dark.toString()}</p>
                                    <p style={getValueStyle(data.blur)}>Blur: {data.blur.toString()}</p>
                                </div>
                                <div style={{ display: 'flex', flexDirection: 'row', justifyContent: 'space-between', width: '100%' }}>
                                    <p style={getValueStyle(data.grayscale)}>Grayscale: {data.grayscale.toString()}</p>
                                    <p style={getValueStyle(data.flashlight)}>Flashlight: {data.flashlight.toString()}</p>
                                </div>
                            </div>
                        </div>
                    </div>
                )}
            </div>
        </div>
    )
}

export default Verify

const styles = {
    formGroup: {
        marginTop: '-45px',
    },
    selectWrapper: {
        position: 'relative',
        marginTop: '0', // Adjusted to remove excessive spacing
    },
    select: {
        width: '100%',
        paddingRight: '30px', // Ensures padding for the icon
    },
    chevronIcon: {
        position: 'absolute',
        right: '10px',
        top: '50%',
        transform: 'translateY(-50%)',
        pointerEvents: 'none',
    },
    remainingQuota: {
        display: 'flex', // Ensures the text aligns properly
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '4px', // Adjust spacing from the label
    },
    quotaText: {
        fontSize: '40px',
        color: '#0542cc',
        fontWeight: '600',
    },
    timesText: {
        marginLeft: '8px',
        verticalAlign: 'super',
        fontSize: '20px', // Adjust font size if necessary
    },
    uploadArea: {
        backgroundColor: '#e6f2ff',
        height: '250px',
        cursor: 'pointer',
        marginTop: '1rem',
        paddingTop: '22px',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        border: '1px solid #ced4da',
        borderRadius: '0.25rem',
    },
    uploadIcon: {
        fontSize: '40px',
        color: '#0542cc',
        marginBottom: '7px',
    },
    uploadText: {
        color: '#1f2d3d',
        fontWeight: '400',
        fontSize: '16px',
        lineHeight: '13px',
    },
    fileWrapper: {
        backgroundColor: '#fff',
        border: '0.2px solid gray',
        padding: '15px 0 0 17px',
        borderRadius: '5px',
        position: 'relative',
        display: 'flex',
        alignItems: 'center',
        gap: '10px',
        justifyContent: 'space-between',
    },        
    fileInfo: {
        marginTop: '4rem',
        display: 'flex',
        alignItems: 'center',
    },
    imageIcon: {
        color: '#0542cc',
        fontSize: '24px',
        marginBottom: '1rem'
    },
    closeIcon: {
        color: 'red',
        cursor: 'pointer',
        fontSize: '26px',
        marginRight: '1rem',
        marginBottom: '1rem'
    },
    submitButton: {
        marginLeft: 'auto',
        marginTop: '4rem',
        textAlign: 'start',
        position: 'relative', // Menambahkan posisi relative
        zIndex: 1, // Menambah z-index jika ada elemen yang menutupi
    },
    uploadError: {
        color: 'red',
        fontSize: '12px',
        marginTop: '5px',
    },

    containerResultStyle: {
        padding: '20px',
        border: '1px solid #ccc',
        borderRadius: '8px',
        backgroundColor: '#f9f9f9',
        marginTop: '20px',
    },
    resultContainer: {
        overflowX: 'auto', // Allows horizontal scrolling if the table is too wide
    },
    tableStyle: {
        width: '100%',
        borderCollapse: 'collapse', // Ensures that table borders are merged
    },
    tableCell: {
        padding: '10px',
        border: '1px solid #ddd', // Light gray border around each cell
        textAlign: 'left',
    },
    loadingOverlay: {
        position: 'fixed',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        backgroundColor: 'rgba(0, 0, 0, 0.2)',
        display: 'flex',
        flexDirection: 'column', 
        justifyContent: 'center',
        alignItems: 'center',
        zIndex: 1000,
    },
    spinner: {
        border: '4px solid rgba(0, 0, 0, 0.1)',
        borderLeftColor: '#0542cc',
        borderRadius: '50%',
        width: '90px',
        height: '90px',
        animation: 'spin 1s ease-in-out infinite',
    },
    loadingText: {
        marginTop: '10px',
        fontSize: '1.2rem',
        color: '#fff',
        textAlign: 'center',
    },
};
